@@ -49,19 +49,21 @@ class NotificationEventSerializer(serializers.ModelSerializer):
     attachments = AttachmentSerializer(many=True, required=False)
     template_detail = EmailTemplateSerializer(source='template', read_only=True)
     smtp_provider_detail = MinimalSmtpProviderSerializer(source='smtp_provider', read_only=True)
-    notification_group_detail = MinimalNotificationGroupSerializer(source='notification_group', read_only=True)
+    notification_groups = serializers.PrimaryKeyRelatedField(many=True, queryset=NotificationGroup.actives.all(),
+                                                             required=False, write_only=True)
+    notification_groups_detail = MinimalNotificationGroupSerializer(source='notification_groups', many=True,
+                                                                    read_only=True)
     recipients = serializers.PrimaryKeyRelatedField(many=True, queryset=User.objects.filter(is_active=True),
                                                     required=False)
 
     class Meta:
         model = NotificationEvent
         fields = ['id', 'title', 'smtp_provider', 'smtp_provider_detail', 'template', 'template_detail', 'subject',
-                  'content', 'notification_group', 'notification_group_detail', 'attachments', 'recipients']
+                  'content', 'notification_groups', 'notification_groups_detail', 'attachments', 'recipients']
 
         extra_kwargs = {
             'template': {'write_only': True, 'allow_null': True},
             'smtp_provider': {'write_only': True},
-            'notification_group': {'write_only': True, 'allow_null': True},
         }
 
     def create(self, validated_data):
@@ -98,9 +100,13 @@ class NotificationEventSerializer(serializers.ModelSerializer):
             raise exceptions.ValidationError(detail=_("You do not have permission to access this template."))
         return value
 
-    def validate_notification_group(self, value):
-        if value and ((not value.is_active) or (not self.context['request'].user == value.owner)):
-            raise exceptions.ValidationError(detail=_("You do not have permission to access this notification group."))
+    def validate_notification_groups(self, value):
+        user = self.context['request'].user
+        for notification_group in value:
+            if not notification_group.is_active or notification_group.owner != user:
+                message = _("You do not have permission to access notification group with id: {}.")
+                raise exceptions.ValidationError(detail=message.format(notification_group.id))
+
         return value
 
     def validate_smtp_provider(self, value):
