@@ -35,13 +35,14 @@ class NotificationEventViewSet(mixins.ListModelMixin,
     authentication_classes = [JWTAuthentication]
     permission_classes = [IsAuthenticated, CustomDjangoModelPermissions]
     pagination_class = CustomLimitOffsetPagination
-    filter_backends = [filters.OrderingFilter]
+    filter_backends = [DjangoFilterBackend, filters.OrderingFilter]
     ordering_fields = ['id']
+    filter_fields = ['notification_groups', 'recipients']
 
     def get_queryset(self):
         queryset = super().get_queryset()
-        queryset = queryset.prefetch_related('attachments', 'notification_group__members', 'recipients')
-        queryset = queryset.select_related('smtp_provider', 'template', 'notification_group')
+        queryset = queryset.prefetch_related('attachments', 'notification_groups__members', 'notification_groups')
+        queryset = queryset.prefetch_related('recipients').select_related('smtp_provider', 'template')
         return queryset.filter(owner=self.request.user)
 
     def perform_create(self, serializer):
